from sqlalchemy.orm import Session
from sqlalchemy import create_engine
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker

SQLALCHEMY_DATABASE_URL = "sqlite:///./test.db"

engine = create_engine(SQLALCHEMY_DATABASE_URL, connect_args={"check_same_thread": False})
SessionLocal = sessionmaker(autocommit=False, autoflush=False, bind=engine)

Base = declarative_base()


# Dependency
def get_db():
    db = SessionLocal()
    try:
        yield db
    finally:
        db.close()


def init_db():
    # Import inside function to avoid circular dependency
    from app import models  
    Base.metadata.create_all(bind=engine)


def load_sample_data(session: Session):
    # Import inside function to avoid circular dependency
    from app.data import contacts, return_addresses, dewars, proposals, shipments

    from app import models  # Ensure these imports are correct

    if session.query(models.ContactPerson).first():
        return

    session.add_all(contacts + return_addresses + dewars + proposals + shipments)
    session.commit()